pilot.filemanagement

Package pilot :: Package filemanagement |

# Package filemanagement

source code

Private: Implementation of the filemanagement subsystem.

Submodules
pilot.filemanagement.bliss_adaptor: Bliss based File Transfer Implementation pilot.filemanagement.globusonline_adaptor: Globus Online based File Transfer pilot.filemanagement.gs_adaptor: Google Storage based File Transfer Implementation pilot.filemanagement.irods_adaptor: iRods based File Transfer Implementation pilot.filemanagement.s3_adaptor: Amazon S3 based File Transfer Implementation pilot.filemanagement.ssh_adaptor: SSH-based coordination scheme between manager and agent pilot.filemanagement.webhdfs_adaptor

Variables
| __package__ = `None` hash(x)